==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>رتب</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>أحضر للمقدمة</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>قدّم</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>أخّر</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>أرسل للخلف</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>اختر هذه</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>انسخ</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>ألصق</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>حرر</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>احذف</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>إعدادات عامة</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>إعدادات الصورة</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>اللون</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>لون النص</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>العرض</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>مبدأ الرقم</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>عامل التشويش</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>ظل العنصر</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>إعدادات العنصر</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>أغلق</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>أغلق الأخرى</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>أغلق الكل</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>أغلق كل ما على اليسار</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>أغلق كل ما على اليمين</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>أداة التحديد</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>ممكن</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>معطل</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>ألغ</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>س:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>ص:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>ع:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>إ:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>طبق</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>الحدود وملء الرؤية</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>حدود و ملء</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>حدود بدون ملء</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>بدون حدود وبدون ملء</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>حجم الخط</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>عريض</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>مائل</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>مسطر</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>تأثيرات الصورة</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>بلا تأثير</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>ظلال ساقطة</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>رمادي</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>الحدود</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>لون معكوس</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>مقيد</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>عندما يمكن يجبر اللوحة
على تضمين صورة خلفية.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>س:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>ص:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>ع:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>إ:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>طبق</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ألغ</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>اللون:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>لون خلفية اللوحة</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>دور الصورة</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>١٨٠°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>٩٠° اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>٩٠° عكس عقارب الساعة</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>عشوائي</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>تدور القيم الموجبة في اتجاه عقارب الساعة، والقيم السالبة عكس اتجاه عقارب الساعة.
قد يؤدي التناوب بمضاعفات بغير زاوية ٩٠ درجة إلى فقدان الجودة.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>أفقي</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>رأسي</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>حسنا</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ألغ</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>دور</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>اقلب</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>حجم الصورة</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>حافظ على تناسق الأبعاد</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>العرض:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>الإرتفاع:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>حسنا</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ألغ</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>بكسل</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>نسبة</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>ملصق</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>اختار</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>معلم المستطيل</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>معلم قطع ناقص</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>معلم القلم</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نص</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>سهم</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>سهم مزدوج</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>خط</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>طمس</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>مستطيل</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>قطع ناقص</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>مؤشر رقمي</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>ملصق</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>تبكسيل</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>مؤشر النص</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>سهم نص</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>سهم رقم</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>كرر</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>كبر (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>صغر (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>صفر التكبير (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.1.orig.tar.gz: kImageAnnotator-0.7.1/translations/kImageAnnotator_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>رتب</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>أحضر للمقدمة</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>قدّم</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>أخّر</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>أرسل للخلف</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>اختر هذه</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>انسخ</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>ألصق</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>حرر</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>احذف</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>إعدادات عامة</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>إعدادات الصورة</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>اللون</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>لون النص</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>العرض</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>مبدأ الرقم</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>عامل التشويش</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>ظل العنصر</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>إعدادات العنصر</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>أغلق</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>أغلق الأخرى</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>أغلق الكل</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>أغلق كل ما على اليسار</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>أغلق كل ما على اليمين</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>أداة التحديد</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>ممكن</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>معطل</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">دور</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>ألغ</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>س:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>ص:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>ع:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>إ:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>طبق</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">رأسي</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">أفقي</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">طبق</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">ألغ</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>الحدود وملء الرؤية</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>حدود و ملء</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>حدود بدون ملء</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>بدون حدود وبدون ملء</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>حجم الخط</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>عريض</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>مائل</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>مسطر</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>تأثيرات الصورة</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>بلا تأثير</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>ظلال ساقطة</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>رمادي</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>الحدود</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>لون معكوس</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>مقيد</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>عندما يمكن يجبر اللوحة
على تضمين صورة خلفية.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>س:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>ص:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>ع:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>إ:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>طبق</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ألغ</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>اللون:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>لون خلفية اللوحة</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>دور الصورة</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>١٨٠°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>٩٠° اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>٩٠° عكس عقارب الساعة</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>عشوائي</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>تدور القيم الموجبة في اتجاه عقارب الساعة، والقيم السالبة عكس اتجاه عقارب الساعة.
قد يؤدي التناوب بمضاعفات بغير زاوية ٩٠ درجة إلى فقدان الجودة.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>أفقي</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>رأسي</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>حسنا</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ألغ</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>دور</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>اقلب</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>حجم الصورة</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>حافظ على تناسق الأبعاد</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>العرض:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>الإرتفاع:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>حسنا</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ألغ</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>بكسل</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>نسبة</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>ملصق</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>اختار</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>قلم</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>رقم</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>معلم المستطيل</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>معلم قطع ناقص</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>معلم القلم</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>نص</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>سهم</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>سهم مزدوج</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>خط</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>طمس</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>مستطيل</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>قطع ناقص</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>مؤشر رقمي</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>ملصق</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>تبكسيل</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>مؤشر النص</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>سهم نص</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>سهم رقم</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>كرر</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>كبر (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>صغر (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>صفر التكبير (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
